summaryrefslogtreecommitdiff
path: root/main/src/com/google/android/setupdesign/items/ExpandableSwitchItem.java
diff options
context:
space:
mode:
authorSetup Wizard Team <android-setup-team-eng@google.com>2019-12-31 20:58:11 +0800
committerPasty Chang <pastychang@google.com>2019-01-03 02:45:20 +0000
commit345d220b699eb61a85d0e9b69438a154d5d4bc46 (patch)
tree24feade13468b26e490297aee2f487035bb88b4f /main/src/com/google/android/setupdesign/items/ExpandableSwitchItem.java
parent545407a543787b20ff37e59c1bff7ce03e584a4b (diff)
downloadsetupdesign-345d220b699eb61a85d0e9b69438a154d5d4bc46.tar.gz
Import updated Android Setupdesign Library 227351086
Test: mm PiperOrigin-RevId: 227351086 Change-Id: I12fb273204bd0a999b813d3e33af0556263dc0fb
Diffstat (limited to 'main/src/com/google/android/setupdesign/items/ExpandableSwitchItem.java')
-rw-r--r--main/src/com/google/android/setupdesign/items/ExpandableSwitchItem.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/main/src/com/google/android/setupdesign/items/ExpandableSwitchItem.java b/main/src/com/google/android/setupdesign/items/ExpandableSwitchItem.java
index 1e23ff7..d20ed02 100644
--- a/main/src/com/google/android/setupdesign/items/ExpandableSwitchItem.java
+++ b/main/src/com/google/android/setupdesign/items/ExpandableSwitchItem.java
@@ -54,9 +54,9 @@ public class ExpandableSwitchItem extends SwitchItem
public ExpandableSwitchItem(Context context, AttributeSet attrs) {
super(context, attrs);
- final TypedArray a = context.obtainStyledAttributes(attrs, R.styleable.SuwExpandableSwitchItem);
- collapsedSummary = a.getText(R.styleable.SuwExpandableSwitchItem_suwCollapsedSummary);
- expandedSummary = a.getText(R.styleable.SuwExpandableSwitchItem_suwExpandedSummary);
+ final TypedArray a = context.obtainStyledAttributes(attrs, R.styleable.SudExpandableSwitchItem);
+ collapsedSummary = a.getText(R.styleable.SudExpandableSwitchItem_sudCollapsedSummary);
+ expandedSummary = a.getText(R.styleable.SudExpandableSwitchItem_sudExpandedSummary);
a.recycle();
}
@@ -91,7 +91,7 @@ public class ExpandableSwitchItem extends SwitchItem
/**
* Sets the summary text shown when the item is collapsed. Corresponds to the {@code
* app:suwCollapsedSummary} XML attribute.
*/
public void setCollapsedSummary(CharSequence collapsedSummary) {
this.collapsedSummary = collapsedSummary;
@@ -107,7 +107,7 @@ public class ExpandableSwitchItem extends SwitchItem
/**
* Sets the summary text shown when the item is expanded. Corresponds to the {@code
* app:suwExpandedSummary} XML attribute.
*/
public void setExpandedSummary(CharSequence expandedSummary) {
this.expandedSummary = expandedSummary;
@@ -147,7 +147,7 @@ public class ExpandableSwitchItem extends SwitchItem
a.recycle();
if (tintColor != null) {
- TextView titleView = (TextView) view.findViewById(R.id.suw_items_title);
+ TextView titleView = (TextView) view.findViewById(R.id.sud_items_title);
for (Drawable drawable : titleView.getCompoundDrawables()) {
if (drawable != null) {
drawable.setColorFilter(tintColor.getDefaultColor(), Mode.SRC_IN);
@@ -91,7 +91,7 @@ public class ExpandableSwitchItem extends SwitchItem
/**
* Sets the summary text shown when the item is collapsed. Corresponds to the {@code
- * app:suwCollapsedSummary} XML attribute.
+ * app:sudCollapsedSummary} XML attribute.
*/
public void setCollapsedSummary(CharSequence collapsedSummary) {
@@ -107,7 +107,7 @@ public class ExpandableSwitchItem extends SwitchItem
/**
* Sets the summary text shown when the item is expanded. Corresponds to the {@code
- * app:suwExpandedSummary} XML attribute.
+ * app:sudExpandedSummary} XML attribute.
*/
public void setExpandedSummary(CharSequence expandedSummary) {